# hhp-render [![build status](https://secure.travis-ci.org/thlorenz/hhp-render.png)](http://travis-ci.org/thlorenz/hhp-render)

Renders PokerHands parsed with hhp to different formats, i.e. PokerStars and message boards.

## Usage

```js
const parse = require('hhp')
const analyze = require('hha')
const { script, summary } = require('hha')
const { renderHtml } = require('hhp-render')

const txt = fs.readFileSync(file, 'utf8')
const parsed = parse(txt)
const analyzed = analyze(parsed)
const scripted = script(analyzed)
const summarized = summarize(scripted)

const rendered = renderHtml({ summary })
console.log(rendered) // prints hand in html format
```

## Status

Renders to html, different forums and PokerStars.
Note that _only_ for PokerStars a binary interface has been exposed.
Also all renderers require a script produced with `hha` except for PokerStars which renders a hand that was parsed with
`hhp` but not analyzed.

```sh
hhp-render <source-dir> <target-dir> --noreveal

  Converts hand histories inside source dir to
  PokerStars format and writes them to the target dir.

  If --noreveal is NOT supplied revealed hands will be
  included as mucked hands.
```

## Installation

    npm install hhp-render

## [API](https://thlorenz.github.io/hhp-render)

<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### renderPokerStars

Renders an hhp parsed hand in PokerStars format.

**Parameters**

-   `hand` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** the parsed hand
-   `$0` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** options
    -   `$0.muckRevealed` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)?** if `true` includes cards revealed via Ignition as mucks (optional, default `true`)

Returns **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** hand rendered to be importable as PokerStars hand

### renderHtml

Renders an hhp parsed + hha anazlyzed + scripted and then summarized hand
to HTML format.

**Parameters**

-   `$0` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** the configuration of the renderer
    -   `$0.text` **[String](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)?** text to start with (optional, default `''`)
    -   `$0.summary` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** the parsed then analyzed, scripted and summarized
    -   `$0.amountAsBB` **[Boolean](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Boolean)?** show all amounts in big blind dominatians (optional, default `false`)
    -   `$0.showHeroCards` **[Boolean](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Boolean)?** show hero cards as part of hands (i.e. don't hide in spoilers) (optional, default `true`)

Returns **[String](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** the rendered hand

### renderFacebook

Renders an hhp parsed + hha anazlyzed + scripted and then summarized hand
to facebook format.

**Parameters**

-   `$0` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** the configuration of the renderer (same as `renderHtml`)

Returns **[String](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** the rendered hand

### forums.renderTwoPlusTwo

Renders an hhp parsed + hha anazlyzed + scripted and then summarized hand
to 2+2 forum format.

**Parameters**

-   `$0` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** the configuration of the renderer (same as `renderHtml`)

Returns **[String](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** the rendered hand

### forums.renderPocketFives

Renders an hhp parsed + hha anazlyzed + scripted and then summarized hand
to pocket fives forum format
PokerXFactor, CardRunners, IntelliPoker formats are identical.

**Parameters**

-   `$0` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** the configuration of the renderer (same as `renderHtml`)

Returns **[String](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** the rendered hand

## License

MIT
